pub struct DraftValueSources {
pub direction: DraftValueSource,
pub pv_range_high: DraftValueSource,
pub pv_range_low: DraftValueSource,
pub mv_range_high: DraftValueSource,
pub mv_range_low: DraftValueSource,
}Expand description
Per-direction/range source choices in the New Tune mapping editor.
Fields
direction: DraftValueSourcepv_range_high: DraftValueSourcepv_range_low: DraftValueSourcemv_range_high: DraftValueSourcemv_range_low: DraftValueSourceTrait Implementations
Sourceimpl Clone for DraftValueSources
impl Clone for DraftValueSources
Sourcefn clone(&self) -> DraftValueSources
fn clone(&self) -> DraftValueSources
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DraftValueSources
impl ComposeSchema for DraftValueSources
Sourceimpl Debug for DraftValueSources
impl Debug for DraftValueSources
Sourceimpl<'de> Deserialize<'de> for DraftValueSources
impl<'de> Deserialize<'de> for DraftValueSources
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DraftValueSources
impl PartialEq for DraftValueSources
Sourcefn eq(&self, other: &DraftValueSources) -> bool
fn eq(&self, other: &DraftValueSources) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DraftValueSources
impl Serialize for DraftValueSources
impl StructuralPartialEq for DraftValueSources